pub struct HtmlConfigBuilder { /* private fields */ }Expand description
Builder for constructing HtmlConfig instances.
Provides a fluent interface for creating and customizing HTML configuration options.
Implementations
Sourceimpl HtmlConfigBuilder
impl HtmlConfigBuilder
Sourcepub fn with_syntax_highlighting(
self,
enable: bool,
theme: Option<String>,
) -> Self
pub fn with_syntax_highlighting( self, enable: bool, theme: Option<String>, ) -> Self
Enables or disables syntax highlighting for code blocks.
Arguments
enable- Whether to enable syntax highlightingtheme- Optional theme name for syntax highlighting
Sourcepub fn with_language(self, language: impl Into<String>) -> Self
pub fn with_language(self, language: impl Into<String>) -> Self
Sourcepub fn build(self) -> Result<HtmlConfig>
pub fn build(self) -> Result<HtmlConfig>
Builds the configuration, validating all settings.
Returns
Returns the validated configuration or an error if validation fails.