pub enum WcagLevel {
A,
AA,
AAA,
}Expand description
WCAG Conformance Levels.
Examples
use html_generator::accessibility::WcagLevel;
assert_eq!(WcagLevel::AA.to_string(), "AA");Variants
A
Level A: Minimum level of conformance Essential accessibility features that must be supported
AA
Level AA: Addresses major accessibility barriers Standard level of conformance for most websites
AAA
Level AAA: Highest level of accessibility conformance Includes additional enhancements and specialized features